==> bootstrap-2.6.1.tgz: package/HandIndex/HandIndex.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const HandIndex = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 16 16"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M6.75 1a.75.75 0 00-.75.75V9a.5.5 0 01-1 0v-.89l-1.003.2a.5.5 0 00-.399.546l.345 3.105a1.5 1.5 0 00.243.666l1.433 2.15a.5.5 0 00.416.223h6.385a.5.5 0 00.434-.252l1.395-2.442a2.5 2.5 0 00.317-.991l.272-2.715a1 1 0 00-.995-1.1H13.5v1a.5.5 0 01-1 0V7.154a4.208 4.208 0 00-.2-.26c-.187-.222-.368-.383-.486-.43-.124-.05-.392-.063-.708-.039a4.844 4.844 0 00-.106.01V8a.5.5 0 01-1 0V5.986c0-.167-.073-.272-.15-.314a1.657 1.657 0 00-.448-.182c-.179-.035-.5-.04-.816-.027l-.086.004V8a.5.5 0 01-1 0V1.75A.75.75 0 006.75 1zM8.5 4.466V1.75a1.75 1.75 0 00-3.5 0v5.34l-1.199.24a1.5 1.5 0 00-1.197 1.636l.345 3.106a2.5 2.5 0 00.405 1.11l1.433 2.15A1.5 1.5 0 006.035 16h6.385a1.5 1.5 0 001.302-.756l1.395-2.441a3.5 3.5 0 00.444-1.389l.272-2.715a2 2 0 00-1.99-2.199h-.582a5.184 5.184 0 00-.195-.248c-.191-.229-.51-.568-.88-.716-.364-.146-.846-.132-1.158-.108l-.132.012a1.26 1.26 0 00-.56-.642 2.634 2.634 0 00-.738-.288c-.31-.062-.739-.058-1.05-.046l-.048.002zm2.094 2.025z"
  }));
});
HandIndex.displayName = 'HandIndex';
export const HandIndexDimensions = {
  height: 16,
  width: 16
};

==> bootstrap-2.11.0.tgz: package/HandIndex/HandIndex.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var HandIndex = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 16 16"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M6.75 1a.75.75 0 00-.75.75V9a.5.5 0 01-1 0v-.89l-1.003.2a.5.5 0 00-.399.546l.345 3.105a1.5 1.5 0 00.243.666l1.433 2.15a.5.5 0 00.416.223h6.385a.5.5 0 00.434-.252l1.395-2.442a2.5 2.5 0 00.317-.991l.272-2.715a1 1 0 00-.995-1.1H13.5v1a.5.5 0 01-1 0V7.154a4.208 4.208 0 00-.2-.26c-.187-.222-.368-.383-.486-.43-.124-.05-.392-.063-.708-.039a4.844 4.844 0 00-.106.01V8a.5.5 0 01-1 0V5.986c0-.167-.073-.272-.15-.314a1.657 1.657 0 00-.448-.182c-.179-.035-.5-.04-.816-.027l-.086.004V8a.5.5 0 01-1 0V1.75A.75.75 0 006.75 1zM8.5 4.466V1.75a1.75 1.75 0 00-3.5 0v5.34l-1.199.24a1.5 1.5 0 00-1.197 1.636l.345 3.106a2.5 2.5 0 00.405 1.11l1.433 2.15A1.5 1.5 0 006.035 16h6.385a1.5 1.5 0 001.302-.756l1.395-2.441a3.5 3.5 0 00.444-1.389l.272-2.715a2 2 0 00-1.99-2.199h-.582a5.184 5.184 0 00-.195-.248c-.191-.229-.51-.568-.88-.716-.364-.146-.846-.132-1.158-.108l-.132.012a1.26 1.26 0 00-.56-.642 2.634 2.634 0 00-.738-.288c-.31-.062-.739-.058-1.05-.046l-.048.002zm2.094 2.025z"
  }));
});
HandIndex.displayName = 'HandIndex';
export var HandIndexDimensions = {
  height: 16,
  width: 16
};
